@@ -190,8 +190,18 @@ def python_type_name(value):
         # @TODO []: documentation for python_type_name
     '''
 
-    value = value.lower()
-    for type_name,val in VALID_PYTHON_TYPES.items():
-        if value in val:
-            return type_name
-    return None
\ No newline at end of file
+    results = []
+    if isinstance(value,(str)):
+        value = [value]
+    
+    for test_val in value:
+        test_val = test_val.lower()
+        for type_name,val in VALID_PYTHON_TYPES.items():
+            if test_val in val:
+                results.append(type_name)
+    results = list(set(results))
+    if len(results) == 0:
+        return None
+    if len(results) == 1:
+        return results[0]
+    return results
\ No newline at end of file
