@@ -21,7 +21,44 @@ import urllib.parse
 import utils.objectUtils as obj
 
 
-def to_snake_case(subject):
+
+
+
+def to_pascal_case(subject,firstCharLower=False,firstCharAlpha=True):
+    subject = re.sub(r'[^a-zA-Z0-9_\s]', ' ', subject)
+
+    subject = to_snake_case(subject)
+    subject = re.sub(r'([a-zA-Z0-9])([a-zA-Z0-9]*)', lambda x: x.group(1).upper() + x.group(2).lower(), subject)
+
+    if firstCharAlpha:
+        subject = re.sub(r'^[^a-zA-Z]*', r'', subject)
+    else:
+        firstCharLower=False
+    subject = re.sub(r'_', '', subject)
+
+    if firstCharLower:
+        subject = re.sub(r'^([A-Za-z])', lambda x: x.group(1).upper(), subject)
+
+    return subject
+
+def to_camel_case(subject,firstCharLower=True,firstCharAlpha=True):
+    subject = re.sub(r'[^a-zA-Z0-9_\s]', ' ', subject)
+
+    subject = to_snake_case(subject)
+    subject = re.sub(r'([a-zA-Z0-9])([a-zA-Z0-9]*)', lambda x: x.group(1).upper() + x.group(2).lower(), subject)
+
+    if firstCharAlpha:
+        subject = re.sub(r'^[^a-zA-Z]*', r'', subject)
+    else:
+        firstCharLower=False
+    subject = re.sub(r'_', '', subject)
+
+    if firstCharLower:
+        subject = re.sub(r'^([A-Za-z])', lambda x: x.group(1).lower(), subject)
+
+    return subject
+
+def to_snake_case(subject,firstCharAlpha=False):
     '''
         Convert a subject to snake case.
 
@@ -41,8 +78,13 @@ def to_snake_case(subject):
         BeepBoop Bleep blorp => beep_boop_bleep_blorp
     '''
     subject = str(subject)
-    subject = re.sub(r'([a-z])([A-Z])', r'\1_\2', subject)
-    subject = subject.replace(' ', '_')
+
+    if firstCharAlpha:
+        subject = re.sub(r'^[^a-zA-Z]*',"",subject)
+
+    subject = re.sub(r'[^a-zA-Z0-9_\s]'," ",subject)
+    subject = re.sub(r'(\s|_)+',"_",subject)
+    subject = re.sub(r'([a-z])(?:\s|_)?([A-Z])',r"\1_\2",subject)
     return subject.lower()
 
 
@@ -65,8 +107,18 @@ def to_screaming_snake(subject):
         ----------            
         BeepBoop Bleep blorp => BEEP_BOOP_BLEEP_BLORP
     '''
+    
     return to_snake_case(subject).upper()
 
+def to_kebab_case(subject):
+    subject = to_snake_case(subject)
+    return subject.replace("_","-")
+
+def to_dot_notation(subject):
+    subject = to_snake_case(subject)
+    return subject.replace("_",".")
+
+
 
 def limit_length(subject, max_len=2, from_beginning=True):
     '''
@@ -595,7 +647,9 @@ def reverse_title_case(value):
         return result[0]
     else:
         return result
-    
+
+
+
 
 # ----------========== ALIASES ==========----------
 left_pad = leftPad
